@@ -1,6 +1,6 @@
 import contextlib
 import os
-from typing import Any
+from typing import Any, Optional
 from typing import Dict
 from typing import List
 from typing import Type
@@ -54,7 +54,6 @@ class Multi:
         return Multi(self.confs + [conf], self.strict, **kwargs)
 
     def string(self, s: str, loader: str = HOCON, **kwargs) -> "Multi":
-
         if loader == YAML:
             data = safe_load(s)
             return self.dict(data, **kwargs)
@@ -72,8 +71,19 @@ class Multi:
         conf = ConfigFactory.parse_URL(uri, timeout=timeout, required=True)
         return Multi(self.confs + [conf], self.strict, **kwargs)
 
-    def file(self, path: str, **kwargs) -> "Multi":
-        if path.endswith(".yaml") or path.endswith(".yml"):
+    def file(
+        self,
+        path: str,
+        loader: Optional[str] = None,
+        allow_missing: bool = False,
+        **kwargs,
+    ) -> "Multi":
+        if allow_missing and not os.path.exists(path):
+            return self.dict({}, **kwargs)
+
+        if loader == YAML or (
+            loader is None and (path.endswith(".yaml") or path.endswith(".yml"))
+        ):
             with open(path, "r") as f:
                 data = safe_load(f)
             return self.dict(data, **kwargs)
